Loan

Responsible: | Administrator | Client: | Client
Branch: | Stoq Roupas e Acessórios Ltda | Removed by: |
Opening date: | 01/01/12 | Expiring date: | 01/01/12

Code | Category | Item | Quantity | Price | Total
|  | Description | 0 | $10.00 | $ 0.00
|  | Description | 1 | $10.00 | $10.00
|  | Description | 2 | $10.00 | $20.00
Total: $30.00

I inform and sign up to receive the items in full working order and I am aware of the responsability that I have for returning them, as well as the return of the amounts involved, in case of loss, damage or any event that make the product unusable.
Client

# Promissory Note

## Payment local

Stoq Roupas e Acessórios Ltda - 24.198.774/7322-35
Avendia São Carlos 2333, Centro
São Carlos / SP

## Issuer

Client
Mainstreet 138, Cidade Araci
Los Angeles / Californa

Number: | 00666
Emission date: | 01 de January de 2012
Due date: | 01 de January de 2012
Value: | $30.00